@@ -18,7 +18,6 @@ from cloudmesh.shell.command import command
 from cloudmesh.shell.command import map_parameters
 from cloudmesh.host.HostCreate import HostCreate
 from cloudmesh.common.sudo import Sudo
-from cloudmesh.common.util import writefile
 
 
 class HostCommand(PluginCommand):
@@ -49,7 +48,7 @@ class HostCommand(PluginCommand):
               host passwd NAMES USER
               host addsudo NAMES USER
               host deluser NAMES USER
-              host config proxy PROXY NAMES
+              host config proxy PROXY NAMES [--append]
 
 
           This command does some useful things.
@@ -66,7 +65,7 @@ class HostCommand(PluginCommand):
 
               host scp NAMES SOURCE DESTINATION
 
-                TBD
+                Uses scp to transfer Source to NAMES:DESTINATION.
 
               host ssh NAMES COMMAND
 
@@ -236,6 +235,7 @@ class HostCommand(PluginCommand):
                        'output',
                        'user',
                        'port',
+                       'append',
                        )
         dryrun = arguments.dryrun
 
@@ -269,9 +269,13 @@ class HostCommand(PluginCommand):
 
         elif arguments.scp and not arguments.key:
 
-            destinations = Parameter.expand(arguments.DESTINATION)
-            source = arguments.SOURCE
-            results_key = Host.scp(source, destinations, output="lines")  # noqa: F841
+            result = Host.put(
+                hosts=arguments.NAMES,
+                source=arguments.SOURCE,
+                destination=arguments.DESTINATION
+            )
+
+            _print(result)
 
         elif arguments.ssh:
             names = Parameter.expand(arguments.NAMES)
@@ -327,7 +331,6 @@ class HostCommand(PluginCommand):
             if not os.path.isfile(filename):
                 Console.error(f"Cannot find file {filename}")
                 return
-            
             # Copy to temp location
             remote_temp = "~/.ssh/key.tmp"
             Host.put(
@@ -398,14 +401,14 @@ class HostCommand(PluginCommand):
                 command = f'sudo mkdir -p /home/' \
                           f'{user}/.ssh/'
                 result = Host.ssh(hosts=names,
-                                   command=command)
+                                  command=command)
                 _print(result)
 
                 Console.info(f'Chown /home/{user}/.ssh to {user}')
                 command = f'sudo chown {user}:{user} /home/' \
                           f'{user}/.ssh/'
                 result = Host.ssh(hosts=names,
-                                   command=command)
+                                  command=command)
                 _print(result)
 
                 Console.info(f'Chmod /home/{user}/.ssh to 700')
@@ -420,7 +423,7 @@ class HostCommand(PluginCommand):
                 command = f'sudo mv temp_authorized_keys_temp /home/' \
                           f'{user}/.ssh/authorized_keys'
                 result = Host.ssh(hosts=names,
-                                   command=command)
+                                  command=command)
                 _print(result)
 
                 Console.info(f'Chown /home/{user}/.ssh/authorized_keys to '
@@ -428,7 +431,7 @@ class HostCommand(PluginCommand):
                 command = f'sudo chown {user}:{user} /home/' \
                           f'{user}/.ssh/authorized_keys'
                 result = Host.ssh(hosts=names,
-                                   command=command)
+                                  command=command)
                 _print(result)
 
         elif arguments.config and not arguments.proxy:
@@ -518,13 +521,22 @@ class HostCommand(PluginCommand):
             localhost = None
             if "localhost" in names:
                 names.remove("localhost")
-                localhost =True
+                localhost = True
             if hostname in names:
                 names.remove(hostname)
                 localhost = True
 
-            Host.ssh(hosts=names, command=command)
-            # _print(results)
+            manager, workers = Host.get_hostnames(names)
+
+            if workers:
+                Console.info(f'Executing `{command}` for {workers}')
+                Host.ssh(hosts=workers, command=command)
+
+            if manager:
+                Console.info(f'Executing `{command}` for {manager}')
+                Host.ssh(hosts=manager, command=command)
+
+            #_print(results)
             # results can be misleading becuase there is a race between the
             # shutdown and the error code being returned from the ssh processes.
 
@@ -544,8 +556,8 @@ class HostCommand(PluginCommand):
             if localhost in names:
                 print('\nAdding user to localhost')
                 result = Shell.run(f'sudo adduser {user} '
-                                      f'--disabled-password '
-                                      f'--gecos "" ')
+                                   f'--disabled-password '
+                                   f'--gecos "" ')
                 print(result)
                 names.remove(localhost)
 
@@ -643,7 +655,7 @@ class HostCommand(PluginCommand):
             user = arguments.PROXY.split('@')[0]
             names = Parameter.expand(arguments.NAMES)
             proxy = arguments.PROXY
-            proxy_host = arguments.PROXY.split('@')[1].replace(".local","")
+            proxy_host = arguments.PROXY.split('@')[1].replace(".local", "")
 
             ssh_config_output = f'\n##### CLOUDMESH PROXY CONFIG #####\n'\
                                 f'Host {proxy_host}\n' \
@@ -659,7 +671,7 @@ class HostCommand(PluginCommand):
                                       f'     StrictHostKeyChecking no\n\n'
                 ssh_config_output += ssh_config_template
 
-            ssh_config_output += f'##### CLOUDMESH PROXY CONFIG #####\n'
+            ssh_config_output += '##### CLOUDMESH PROXY CONFIG #####\n'
 
             print('Adding to ~/.ssh/config')
             print(ssh_config_output)
@@ -672,15 +684,20 @@ class HostCommand(PluginCommand):
                 lines = f.readlines()
                 f.close()
                 with open(path_expand('~/.ssh/config'), 'w+') as f:
-                    if f'##### CLOUDMESH PROXY CONFIG #####\n' in lines:
+                    if '##### CLOUDMESH PROXY CONFIG #####\n' in lines:
                         start = lines.index('##### CLOUDMESH PROXY CONFIG #####\n')
                         lines.reverse()
                         end = lines.index('##### CLOUDMESH PROXY CONFIG #####\n')
                         end = len(lines) - end - 1
                         lines.reverse()
-                        del lines[start:end+1]
+                        original_config = lines[start:end + 1]
+                        del lines[start:end + 1]
                         f.writelines(lines)
-                        f.write(ssh_config_output)
+                        if arguments.append:
+                            f.writelines(original_config)
+                            f.write(ssh_config_output)
+                        else:
+                            f.write(ssh_config_output)
                     else:
                         f.writelines(lines)
                         f.write(ssh_config_output)
