@@ -7,9 +7,9 @@ from cloudmesh.inventory.inventory import Inventory
 from cloudmesh.shell.command import PluginCommand
 from cloudmesh.shell.command import command, map_parameters
 from cloudmesh.common.Host import Host
-from cloudmesh.common.Shell import Shell
 from cloudmesh.common.util import path_expand
 
+
 class InventoryCommand(PluginCommand):
 
     # noinspection PyUnusedLocal
@@ -30,6 +30,9 @@ class InventoryCommand(PluginCommand):
                                   [--service=SERVICE]
                                   [--tag=TAG]
                                   [--keyfile=KEYFILE]
+                                  [--router=ROUTER]
+                                  [--locale=LOCALE]
+                                  [--timezone=TIMEZONE]
               inventory create TAG [--hostnames=NAMES]
                                    [--ip=IP]
                                    [--inventory=INVENTORY]
@@ -173,8 +176,7 @@ class InventoryCommand(PluginCommand):
             keyfile = arguments.keyfile or '~/.ssh/id_rsa.pub'
 
             if arguments.inventory is None:
-                Console.error("Missing --inventory param")
-                return
+                arguments.inventory = "inventory.yaml"
 
             if manager is None:
                 manager_ip = None
@@ -185,7 +187,6 @@ class InventoryCommand(PluginCommand):
 
             worker_hostnames = workers
 
-
             if arguments.inventory is None:
                 i = Inventory()
             else:
@@ -283,7 +284,6 @@ class InventoryCommand(PluginCommand):
                     pass
             element['host'] = arguments.NAMES
             element['status'] = 'inactive'
-            element['name'] = arguments.NAMES
             i.add(**element)
             i.save()
             print(i.list(format="table"))
